/*
 *============================================================================
 * blitfuncs.h
 *   This file provides the prototypes for all the blitter funcs, and a few
 *   other blitting related structures and functions.
 *============================================================================
 *  Copyright 2002 
 *        William Baxter
 *        The University of North Carolina at Chapel Hill
 * 
 *  Permission to use, copy, modify, distribute and sell this software
 *  and its documentation for any purpose is hereby granted without
 *  fee, provided that the above copyright notice appear in all copies
 *  and that both that copyright notice and this permission notice
 *  appear in supporting documentation.  Binaries may be compiled with
 *  this software without any royalties or restrictions.
 * 
 *  The University of North Carolina at Chapel Hill makes no
 *  representations about the suitability of this software for any
 *  purpose. It is provided "as is" without express or implied
 *  warranty.
 *============================================================================
 */
#ifndef BLIT_FUNCS_H
#define BLIT_FUNCS_H
#include "imdebug_priv.h"

/*
// THIS IS THE TYPE SIGNATURE OF ALL THE BLITTER FUNCS
typedef void (*PBLITFUNC)(
  BYTE* pDiData, 
  int dstDataW, // W in pixels of bitmap we're copying into
  int dstW, int dstH, int dstX, int dstY, // rect of region to copy to
  BYTE* pSrc,
  int srcDataW, // W in pixels of src data we're copying from
  int srcDataColBytes, // W in bytes of single pixel of data we're copying from
  int srcW, int srcH, int srcX, int srcY,  // subrect of region to copy from
  char *srcChanOffsets,  // precomputed byte offsets for each channel
  ImProps *pProps, // contains all raw data about image
  BlitStats *bs // NULL or a pointer to a BlitStats structure to fill in.
                // when bs!=NULL, pDiData will not be modified.
  );
*/


typedef struct {
  float min[4];//min of r,g,b,a
  float max[4];//max of r,g,b,a
} BlitStats;

void initBlitStats(BlitStats *bs);

// Utility routines (used by imdbgdisplay also)
unsigned int bytePtr2Val_BitOffsets(BYTE*x, int offset, int width);

#define DECLARE_BLITTER(func,attribs) \
void func (BYTE*,int,int,int,int,int,int,BYTE*,int,int,int,int,int,int,char*,ImProps*,BlitStats*);

typedef DECLARE_BLITTER((*PBLITFUNC),_dummy)

// HERE'S WHERE THE MEAT IS
#include "blitfuncdecl.h"

#undef DECLARE_BLITTER

#endif
